| export_xlsx.QR_matrix | R Documentation |
To export a quality report in an Excel file.
## S3 method for class 'QR_matrix'
export_xlsx(x, file, auto_format = TRUE, overwrite = TRUE, ...)
x |
a |
file |
a |
auto_format |
logical indicating whether to format the output
( |
overwrite |
logical indicating whether to create an Excel file if it
doesn't exist yet ( |
... |
other unused arguments |
Returns invisibly (via invisible(x)) a workbook object
created by XLConnect::loadWorkbook() for further manipulation.
Traduction française
Other QR_matrix functions:
export_xlsx(),
export_xlsx.mQR_matrix(),
extract_QR(),
rbind.QR_matrix(),
sort(),
weighted_score()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.