Skip to contents

To export several quality reports in CSV or Excel files

Usage

# S3 method for class 'JVS_matrix'
write(
  x,
  format = c("csv", "xlsx"),
  export_dir = tempdir(),
  overwrite = TRUE,
  ...
)

Arguments

x

a JVS_matrix object to export.

format

output format. One of "csv" or "xlsx". The default is "csv".

export_dir

export directory.

overwrite

logical indicating whether to create a CSV or Excel file if it doesn't exist yet (create = TRUE by default)

...

other unused arguments

Value

Returns invisibly (via invisible(x)) the same JVS_matrix object as x.

Details

  • xlsx files will be exported with the package 'openxlsx'.

  • csv files will be exported with the package 'utils'.