To export several quality reports in Excel files
Arguments
- x
a
mQR_matrixobject to export.- export_dir
export directory.
- layout_file
export parameter. By default, (
layout_file = "ByComponent") and an Excel file is exported for each part of the quality report matrix (modalities and values matrices). To group both modalities and values reports/sheets into a single Excel file, use the optionlayout_file = "ByQRMatrix".- auto_format
logical indicating whether to format the output (
auto_format = TRUEby default).- overwrite
logical indicating whether to create an Excel file if it doesn't exist yet (
create = TRUEby default)- ...
other unused arguments
Value
Returns invisibly (via invisible(x)) the same
mQR_matrix object as x.
See also
Other QR_matrix functions:
extract_QR(),
rbind.QR_matrix(),
sort,
weighted_score(),
write(),
write.JVS_matrix(),
write.QR_matrix()