To export a quality report in an Excel file.
# S3 method for QR_matrix
export_xlsx(x, file, auto_format = TRUE, overwrite = TRUE, ...)Returns invisibly (via invisible(x)) a workbook object
created by XLConnect::loadWorkbook() for further manipulation.
a QR_matrix object.
a character object with the path to the file to export
que l'on veut créer
logical indicating whether to format the output
(auto_format = TRUE by default).
logical indicating whether to create an Excel file if it
doesn't exist yet (create = TRUE by default)
other unused arguments
Traduction française
Other QR_matrix functions:
export_xlsx(),
export_xlsx.mQR_matrix(),
extract_QR(),
rbind.QR_matrix(),
sort(),
weighted_score()