To export several quality reports in CSV or Excel files
Arguments
- x
a
JVS_matrixobject to export.- format
output format. One of
"csv"or"xlsx". The default is"csv".- export_dir
export directory.
- overwrite
logical indicating whether to create a CSV or Excel file if it doesn't exist yet (
create = TRUEby default)- ...
other unused arguments
Value
Returns invisibly (via invisible(x)) the same
JVS_matrix object as x.
Details
xlsx files will be exported with the package 'openxlsx'.
csv files will be exported with the package 'utils'.
See also
Other QR_matrix functions:
extract_QR(),
rbind.QR_matrix(),
sort,
weighted_score(),
write(),
write.QR_matrix(),
write.mQR_matrix()